pub struct MapRange {
    pub offset: usize,
    pub dev: String,
    pub flags: String,
    pub inode: usize,
    /* private fields */
}
A struct representing a single virtual memory region While this structure only is for Linux, the OSX and Windows variants have identical exposed methods

Fields

offset: usizedev: Stringflags: Stringinode: usize

Implementations

Returns the size of this MapRange in bytes

Returns the address this MapRange starts at

Returns the filename of the loaded module

Returns whether this range contains executable code

Returns whether this range contains writeable memory

Returns whether this range contains readable memory