pub struct MapRange {
pub offset: usize,
pub dev: String,
pub flags: String,
pub inode: usize,
/* private fields */
}
A struct representing a single virtual memory region
While this structure only is for Linux, the OSX and Windows
variants have identical exposed methods
Returns the size of this MapRange in bytes
Returns the address this MapRange starts at
Returns the filename of the loaded module
Returns whether this range contains executable code
Returns whether this range contains writeable memory
Returns whether this range contains readable memory
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
This method tests for
self and
other values to be equal, and is used
by
==.
Read more
This method tests for
!=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.